@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import print_function
 from lxml import etree
 from OFS.ObjectManager import ObjectManager
 from plone.app.registry import Registry
@@ -13,12 +14,14 @@ from plone.registry.interfaces import IInterfaceAwareRecord
 from plone.registry.interfaces import IRegistry
 from plone.supermodel.utils import prettyXML
 from plone.testing import zca
+from Products.GenericSetup.tests.common import DummyImportContext as BaseDummyImportContext
 from Products.GenericSetup.tests.common import DummyExportContext
-from Products.GenericSetup.tests.common import DummyImportContext
 from zope.component import provideUtility
 from zope.configuration import xmlconfig
 from zope.interface import alsoProvides
-import unittest2 as unittest
+
+import unittest
+
 
 configuration = """\
 <configure xmlns="http://namespaces.zope.org/zope"
@@ -31,6 +34,17 @@ configuration = """\
 """
 
 
+class DummyImportContext(BaseDummyImportContext):
+
+    _directories = {}
+
+    def listDirectory(self, path):
+        return self._directories.get(path, [])
+
+    def isDirectory(self, path):
+        return path in self._directories
+
+
 class ExportImportTest(unittest.TestCase):
 
     layer = zca.UNIT_TESTING
@@ -60,15 +74,15 @@ class ExportImportTest(unittest.TestCase):
         actual_tree = etree.XML(actual)
 
         if etree.tostring(expected_tree) != etree.tostring(actual_tree):
-            print
-            print "Expected:"
-            print prettyXML(expected_tree)
-            print
+            print()
+            print("Expected:")
+            print(prettyXML(expected_tree))
+            print()
 
-            print
-            print "Actual:"
-            print prettyXML(actual_tree)
-            print
+            print()
+            print("Actual:")
+            print(prettyXML(actual_tree))
+            print()
 
             raise AssertionError(u"XML mis-match")
 
@@ -86,7 +100,7 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
+        self.assertEqual(1, len(self.registry.records))
 
     def test_import_purge(self):
 
@@ -99,7 +113,7 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(0, len(self.registry.records))
+        self.assertEqual(0, len(self.registry.records))
 
     def test_import_records(self):
         xml = """\
@@ -115,13 +129,13 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(3, len(self.registry.records))
+        self.assertEqual(3, len(self.registry.records))
 
-        self.failUnless(
-            'plone.app.registry.tests.data.ITestSettings.name' in self.registry
+        self.assertIn(
+            'plone.app.registry.tests.data.ITestSettings.name', self.registry
         )
-        self.failUnless(
-            'plone.app.registry.tests.data.ITestSettings.age' in self.registry
+        self.assertIn(
+            'plone.app.registry.tests.data.ITestSettings.age', self.registry
         )
 
     def test_import_records_disallowed(self):
@@ -160,14 +174,14 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(3, len(self.registry.records))
+        self.assertEqual(3, len(self.registry.records))
 
-        self.failUnless(
-            'plone.app.registry.tests.data.ITestSettingsDisallowed.name' in
+        self.assertIn(
+            'plone.app.registry.tests.data.ITestSettingsDisallowed.name',
             self.registry
         )
-        self.failUnless(
-            'plone.app.registry.tests.data.ITestSettingsDisallowed.age' in
+        self.assertIn(
+            'plone.app.registry.tests.data.ITestSettingsDisallowed.age',
             self.registry
         )
 
@@ -182,7 +196,7 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(2, len(self.registry.records))
+        self.assertEqual(2, len(self.registry.records))
         delete_xml = """\
 <registry>
     <records interface="plone.app.registry.tests.data.ITestSettings" remove="true"/>
@@ -193,7 +207,7 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(0, len(self.registry.records))
+        self.assertEqual(0, len(self.registry.records))
 
     def test_import_records_delete_deprecated(self):
         xml = """\
@@ -206,7 +220,7 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(2, len(self.registry.records))
+        self.assertEqual(2, len(self.registry.records))
         delete_xml = """\
 <registry>
     <records interface="plone.app.registry.tests.data.ITestSettings" delete="true"/>
@@ -217,7 +231,7 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(0, len(self.registry.records))
+        self.assertEqual(0, len(self.registry.records))
 
     def test_import_records_remove_with_omit(self):
         xml = """\
@@ -230,7 +244,7 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(2, len(self.registry.records))
+        self.assertEqual(2, len(self.registry.records))
         delete_xml = """\
 <registry>
     <records interface="plone.app.registry.tests.data.ITestSettings" remove="true">
@@ -243,13 +257,13 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
+        self.assertEqual(1, len(self.registry.records))
 
-        self.failUnless(
-            'plone.app.registry.tests.data.ITestSettings.name' in self.registry
+        self.assertIn(
+            'plone.app.registry.tests.data.ITestSettings.name', self.registry
         )
-        self.failIf(
-            'plone.app.registry.tests.data.ITestSettings.age' in self.registry
+        self.assertNotIn(
+            'plone.app.registry.tests.data.ITestSettings.age', self.registry
         )
 
     def test_import_records_remove_with_value(self):
@@ -263,7 +277,7 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(2, len(self.registry.records))
+        self.assertEqual(2, len(self.registry.records))
         delete_xml = """\
 <registry>
     <records interface="plone.app.registry.tests.data.ITestSettings" remove="true">
@@ -276,7 +290,7 @@ class TestImport(ExportImportTest):
 
         self.assertRaises(ValueError, importRegistry, context)
 
-        self.assertEquals(2, len(self.registry.records))
+        self.assertEqual(2, len(self.registry.records))
 
     def test_import_records_with_prefix(self):
         xml = """\
@@ -289,13 +303,13 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(2, len(self.registry.records))
+        self.assertEqual(2, len(self.registry.records))
 
-        self.failUnless(
-            'plone.app.registry.tests.data.SomethingElse.name' in self.registry
+        self.assertIn(
+            'plone.app.registry.tests.data.SomethingElse.name', self.registry
         )
-        self.failUnless(
-            'plone.app.registry.tests.data.SomethingElse.age' in self.registry
+        self.assertIn(
+            'plone.app.registry.tests.data.SomethingElse.age', self.registry
         )
 
     def test_import_records_with_values(self):
@@ -312,13 +326,13 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(2, len(self.registry.records))
+        self.assertEqual(2, len(self.registry.records))
 
-        self.failUnless(
-            'plone.app.registry.tests.data.SomethingElse.name' in self.registry
+        self.assertIn(
+            'plone.app.registry.tests.data.SomethingElse.name', self.registry
         )
-        self.failUnless(
-            'plone.app.registry.tests.data.SomethingElse.age' in self.registry
+        self.assertIn(
+            'plone.app.registry.tests.data.SomethingElse.age', self.registry
         )
 
         self.assertEqual(
@@ -369,12 +383,12 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.export.simple'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Imported value",
             self.registry['test.export.simple']
         )
@@ -396,12 +410,12 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.export.simple'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Sample value",
             self.registry['test.export.simple']
         )
@@ -423,12 +437,12 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.export.simple'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Imported value",
             self.registry['test.export.simple']
         )
@@ -450,12 +464,12 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.export.simple'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Sample value",
             self.registry['test.export.simple']
         )
@@ -473,12 +487,12 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(
             u"Age",
             self.registry.records['plone.app.registry.tests.data.ITestSettingsDisallowed.age'].field.title  # noqa
         )
-        self.assertEquals(
+        self.assertEqual(
             2,
             self.registry['plone.app.registry.tests.data.ITestSettingsDisallowed.age']  # noqa
         )
@@ -496,12 +510,12 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(
             u"Age",
             self.registry.records['plone.registry.oops'].field.title
         )
-        self.assertEquals(2, self.registry['plone.registry.oops'])
+        self.assertEqual(2, self.registry['plone.registry.oops'])
 
     def test_import_interface_no_value(self):
         xml = """\
@@ -514,12 +528,12 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(
             u"Name",
             self.registry.records['plone.app.registry.tests.data.ITestSettingsDisallowed.name'].field.title  # noqa
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Mr. Registry",
             self.registry['plone.app.registry.tests.data.ITestSettingsDisallowed.name']  # noqa
         )
@@ -540,21 +554,21 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.TextLine)
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             u"value",
             self.registry.records['test.registry.field'].field.__name__
         )
-        self.assertEquals(
+        self.assertEqual(
             u"N/A",
             self.registry['test.registry.field']
         )
@@ -577,20 +591,20 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(2, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(2, len(self.registry.records))
+        self.assertTrue(
             IFieldRef.providedBy(
                 self.registry.records['test.registry.field.override'].field)
             )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field.override'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             u"value",
             self.registry.records['test.registry.field.override'].field.__name__  # noqa
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Another value",
             self.registry['test.registry.field.override']
         )
@@ -611,18 +625,18 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.ASCIILine
             )
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             "N/A",
             self.registry['test.registry.field']
         )
@@ -648,17 +662,17 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.ASCIILine)
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             "Nada",
             self.registry['test.registry.field']
         )
@@ -679,18 +693,18 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.Int
             )
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Age",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             None,
             self.registry['test.registry.field']
         )
@@ -722,18 +736,18 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.FrozenSet
             )
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             frozenset([1, 3]),
             self.registry['test.registry.field']
         )
@@ -763,18 +777,18 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.Set
             )
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             frozenset([4, 6]),
             self.registry['test.registry.field']
         )
@@ -804,18 +818,18 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.Set
             )
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             frozenset([1, 4, 6]),
             self.registry['test.registry.field']
         )
@@ -845,8 +859,8 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals([2, 4, 6], self.registry['test.registry.field'])
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual([2, 4, 6], self.registry['test.registry.field'])
 
     def test_import_collection_tuple_append(self):
         xml = """\
@@ -873,8 +887,8 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(
             (u"a", u"b", u"c", ),
             self.registry['test.registry.field']
         )
@@ -904,8 +918,8 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(set([2, 4, 6]), self.registry['test.registry.field'])
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(set([2, 4, 6]), self.registry['test.registry.field'])
 
     def test_import_collection_frozenset_append(self):
         xml = """\
@@ -932,8 +946,8 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(
             frozenset([2, 4, 6]),
             self.registry['test.registry.field']
         )
@@ -968,18 +982,18 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.Dict
             )
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             {'a': 1, 'b': 3},
             self.registry['test.registry.field']
         )
@@ -1007,18 +1021,18 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.Dict
             )
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             {'x': 4, 'y': 6},
             self.registry['test.registry.field']
         )
@@ -1046,18 +1060,18 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.Dict
             )
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             {'a': 1, 'x': 4, 'y': 6},
             self.registry['test.registry.field']
         )
@@ -1086,22 +1100,22 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.failUnless(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.Choice
             )
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record", self.registry.records['test.registry.field'].
             field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             [u'One', u'Two'],
             [t.value for t in self.registry.records['test.registry.field'].field.vocabulary]  # noqa
         )
-        self.assertEquals(
+        self.assertEqual(
             None, self.registry['test.registry.field']
         )
 
@@ -1128,32 +1142,32 @@ class TestImport(ExportImportTest):
 
         importRegistry(context)
 
-        self.assertEquals(3, len(self.registry.records))
+        self.assertEqual(3, len(self.registry.records))
 
-        self.failUnless(
+        self.assertTrue(
             isinstance(
                 self.registry.records['test.registry.field'].field,
                 field.TextLine
             )
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.registry.field'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             u"value",
             self.registry.records['test.registry.field'].field.__name__
         )
-        self.assertEquals(
+        self.assertEqual(
             u"N/A",
             self.registry['test.registry.field']
         )
 
-        self.failUnless(
-            'plone.app.registry.tests.data.SomethingElse.name' in self.registry
+        self.assertIn(
+            'plone.app.registry.tests.data.SomethingElse.name', self.registry
         )
-        self.failUnless(
-            'plone.app.registry.tests.data.SomethingElse.age' in self.registry
+        self.assertIn(
+            'plone.app.registry.tests.data.SomethingElse.age', self.registry
         )
         self.assertEqual(
             self.registry['plone.app.registry.tests.data.SomethingElse.name'],
@@ -1178,7 +1192,7 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(0, len(self.registry.records))
+        self.assertEqual(0, len(self.registry.records))
 
     def test_delete_deprecated(self):
         xml = """\
@@ -1194,7 +1208,7 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(0, len(self.registry.records))
+        self.assertEqual(0, len(self.registry.records))
 
     def test_delete_not_found(self):
         xml = """\
@@ -1210,16 +1224,83 @@ class TestImport(ExportImportTest):
                    value=u"Sample value")
         importRegistry(context)
 
-        self.assertEquals(1, len(self.registry.records))
-        self.assertEquals(
+        self.assertEqual(1, len(self.registry.records))
+        self.assertEqual(
             u"Simple record",
             self.registry.records['test.export.simple'].field.title
         )
-        self.assertEquals(
+        self.assertEqual(
             u"Sample value",
             self.registry['test.export.simple']
         )
 
+    def test_import_folder(self):
+        xml1 = """\
+<registry>
+    <record name="test.registry.foobar1">
+        <field type="plone.registry.field.TextLine">
+          <default>N/A</default>
+          <title>Simple record</title>
+        </field>
+    </record>
+</registry>
+"""
+        xml2 = """\
+<registry>
+    <record name="test.registry.foobar2">
+        <field type="plone.registry.field.TextLine">
+          <default>N/A</default>
+          <title>Simple record</title>
+        </field>
+    </record>
+</registry>
+"""
+        xml3 = """\
+<registry>
+    <record name="test.registry.foobar3">
+        <field type="plone.registry.field.TextLine">
+          <default>N/A</default>
+          <title>Simple record</title>
+        </field>
+    </record>
+</registry>
+"""
+        context = DummyImportContext(self.site, purge=False)
+        context._files = {
+            'registry.xml': xml1,
+            'registry/foo2.xml': xml2,
+            'registry/foo3.xml': xml3
+        }
+        context._directories = {
+            'registry': [
+                'foo2.xml',
+                'foo3.xml',
+            ]
+        }
+        importRegistry(context)
+
+        self.assertEqual(3, len(self.registry.records))
+
+        for idx in range(1, 4):
+            fieldname = 'test.registry.foobar%i' % idx
+            self.assertTrue(
+                isinstance(
+                    self.registry.records[fieldname].field,
+                    field.TextLine)
+            )
+            self.assertEqual(
+                u"Simple record",
+                self.registry.records[fieldname].field.title
+            )
+            self.assertEqual(
+                u"value",
+                self.registry.records[fieldname].field.__name__
+            )
+            self.assertEqual(
+                u"N/A",
+                self.registry[fieldname]
+            )
+
 
 class TestExport(ExportImportTest):
 
@@ -1229,7 +1310,7 @@ class TestExport(ExportImportTest):
         context = DummyExportContext(self.site)
         exportRegistry(context)
 
-        self.assertEquals('registry.xml', context._wrote[0][0])
+        self.assertEqual('registry.xml', context._wrote[0][0])
         self.assertXmlEquals(xml, context._wrote[0][1])
 
     def test_export_simple(self):
@@ -1252,7 +1333,7 @@ class TestExport(ExportImportTest):
         context = DummyExportContext(self.site)
         exportRegistry(context)
 
-        self.assertEquals('registry.xml', context._wrote[0][0])
+        self.assertEqual('registry.xml', context._wrote[0][0])
         self.assertXmlEquals(xml, context._wrote[0][1])
 
     def test_export_with_interface(self):
@@ -1290,7 +1371,7 @@ class TestExport(ExportImportTest):
         context = DummyExportContext(self.site)
         exportRegistry(context)
 
-        self.assertEquals('registry.xml', context._wrote[0][0])
+        self.assertEqual('registry.xml', context._wrote[0][0])
         self.assertXmlEquals(xml, context._wrote[0][1])
 
     def test_export_field_ref(self):
@@ -1321,7 +1402,7 @@ class TestExport(ExportImportTest):
         context = DummyExportContext(self.site)
         exportRegistry(context)
 
-        self.assertEquals('registry.xml', context._wrote[0][0])
+        self.assertEqual('registry.xml', context._wrote[0][0])
         self.assertXmlEquals(xml, context._wrote[0][1])
 
     def test_export_with_collection(self):
@@ -1351,7 +1432,7 @@ class TestExport(ExportImportTest):
         context = DummyExportContext(self.site)
         exportRegistry(context)
 
-        self.assertEquals('registry.xml', context._wrote[0][0])
+        self.assertEqual('registry.xml', context._wrote[0][0])
         self.assertXmlEquals(xml, context._wrote[0][1])
 
     def test_export_with_dict(self):
@@ -1384,7 +1465,7 @@ class TestExport(ExportImportTest):
         context = DummyExportContext(self.site)
         exportRegistry(context)
 
-        self.assertEquals('registry.xml', context._wrote[0][0])
+        self.assertEqual('registry.xml', context._wrote[0][0])
         self.assertXmlEquals(xml, context._wrote[0][1])
 
     def test_export_with_choice(self):
@@ -1407,7 +1488,7 @@ class TestExport(ExportImportTest):
         context = DummyExportContext(self.site)
         exportRegistry(context)
 
-        self.assertEquals('registry.xml', context._wrote[0][0])
+        self.assertEqual('registry.xml', context._wrote[0][0])
         self.assertXmlEquals(xml, context._wrote[0][1])
 
     def test_export_with_missing_schema_does_not_error(self):
@@ -1440,5 +1521,5 @@ class TestExport(ExportImportTest):
         context = DummyExportContext(self.site)
         exportRegistry(context)
 
-        self.assertEquals('registry.xml', context._wrote[0][0])
+        self.assertEqual('registry.xml', context._wrote[0][0])
         self.assertXmlEquals(xml, context._wrote[0][1])
